.\" -*- nroff -*- generated from .Rd format
.BG
.FN Ellipses
.FN ellipse
.FN data.ellipse
.FN confidence.ellipse
.TL
Ellipses, Data Ellipses, and Confidence Ellipses
.DN
These functions draw ellipses, including data ellipses, and
confidence ellipses for linear and generalized linear models.
The ellipse is computed by suitably transforming a unit circle.
.IP  
`data.ellipse' superimposes the normal-probability contours over a scatterplot
of the data.

.CS
ellipse(center, shape, radius, center.pch = 16, center.cex = 1.5, segments = 
    51, add = T, xlab = "", ylab = "", las = par("las"), col = 2, lwd = 2,
    lty = 1, ...)

data.ellipse(x, y, levels = c(0.5, 0.9), center.pch = 16, center.cex = 1.5, 
    plot.points = T, add = !plot.points, segments = 51, robust = F, xlab = 
    deparse(substitute(x)), ylab = deparse(substitute(y)), las = par("las"),
    col = 2, pch = 1, lwd = 2, lty = 1, ...)

confidence.ellipse(model, ...)

confidence.ellipse.lm(model, which.coef, levels = 0.95, Scheffe = F, center.pch = 16, 
    center.cex = 1.5, segments = 51, xlab, ylab, las = par("las"), col = 2,
    lwd = 2, lty = 1, ...)

confidence.ellipse.glm(model, which.coef, levels = 0.95, Scheffe = F, center.pch = 16, 
    center.cex = 1.5, segments = 51, xlab, ylab, las = par("las"), col = 2,
    lwd = 2, lty = 1, ...)
.RA
.AG center
2-element vector with coordinates of center of ellipse.
.AG shape
2 * 2 shape (or covariance) matrix.
.AG radius
radius of circle generating the ellipse.
.AG x
a numeric vector, or (if `y' is missing) a 2-column numeric matrix.
.AG model
a model object produced by `lm' or `glm'.
.OA
.AG center.pch
character for plotting ellipse center.
.AG center.cex
relative size of character for plotting ellipse center.
.AG segments
number of line-segments used to draw ellipse.
.AG add
if `TRUE' add ellipse to current plot.
.AG xlab
label for horizontal axis.
.AG ylab
label for vertical axis.
.AG y
a numeric vector, of the same length as `x'.
.AG plot.points
if `FALSE' data ellipses are added to the current scatterplot,
but points are not plotted.
.AG levels
draw elliptical contours at these (normal) probability or confidence levels.
.AG robust
if `TRUE' use the `cov.trob' function in the `MASS' library
to calculate the center and covariance matrix for the data ellipse.
.AG which.coef
2-element vector giving indices of coefficients to plot; 
if missing, the first two coefficients (disregarding the regression constant)
will be selected.
.AG Scheffe
if `TRUE' scale the ellipse so that its projections onto the
axes give Scheffe confidence intervals for the coefficients.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; the default is `2'.
and `par').
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
.AG lty
line type; default is `1', a solid line (see `par').
.AG ...
other plotting parameters to be passed to `plot' and
`line'.
.RT
`NULL'. These functions are used for their side effect: producing
plots.
.SH REFERENCES
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.IP 
Monette, G. (1990)
Geometry of multiple regression and 3D graphics.
In Fox, J. and Long, J. S. (Eds.) 
Modern Methods of Data Analysis. Sage.
.EX
attach(Prestige)
data.ellipse(income, education, levels=0.1*1:9, lty=2)
confidence.ellipse(lm(prestige~income+education), Scheffe=T)
.KW hplot
.KW aplot
.WR
