.\" -*- nroff -*- generated from .Rd format
.BG
.FN TransformationAxes
.FN power.axis
.FN box.cox.axis
.FN prob.axis
.TL
Axes for Transformed Variables
.DN
These functions produce axes for the original scale of 
transformed variables. Typically these would appear as additional
axes to the right or
at the top of the plot, but if the plot is produced with 
`axes=F', then these functions could be used for axes below or to
the left of the plot as well.
.CS
power.axis(power, base = exp(1), side = c("right", "above", "left", "below"),
    at, grid = F, grid.col = 2, grid.lty = 3, axis.title = 
    "Untransformed Data", cex = 1, las = par("las"))

box.cox.axis(power, side = c("right", "above", "left", "below"), at, grid = F,
    grid.col = 2, grid.lty = 3, axis.title = "Untransformed Data", cex = 1,
    las = par("las"))

prob.axis(at, side = c("right", "above", "left", "below"), grid = F, grid.lty = 
    3, grid.col = 2, axis.title = "Probability", interval = 0.1, cex = 1,
    las = par("las"))
.RA
.AG power
power for Box-Cox or power transformation. Specify `0' for logs.
.OA
.AG side
side at which the axis is to be drawn; numeric
codes are also permitted: `side = 1' for the bottom of the plot,
`side=2' for the left side, 
`side = 3' for the top, `side = 4' for the right side.
.AG at
numeric vector giving location of tick marks on
original scale; if missing, the function will try to pick
nice locations for the ticks.
.AG grid
if `TRUE' grid lines for the axis will be drawn.
.AG grid.col
color of grid lines.
.AG grid.lty
line type for grid lines.
.AG axis.title
title for axis.
.AG cex
relative character expansion for axis label.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG base
base of log transformation for `power.axis'
when `power = 0'.
.AG interval
desired interval between tick marks on the probability
scale.
.RT
These functions are used for their side effects: to draw axes.

.SA
`box.cox', `logit'
.EX
UN<-na.omit(UN)
attach(UN)
par(mar=c(5, 4, 4, 4)+.1)

plot(logb(gdp, 10), logb(infant.mortality, 10))
power.axis(0, base=10, side="above", 
  at=c(50,200,500,2000,5000,20000),grid=T, axis.title="GDP per capita")
power.axis(0, base=10, side="right",
  at=c(5,10,20,50,100), grid=T, axis.title="infant mortality rate per 1000")

plot(box.cox(gdp, 0), box.cox(infant.mortality, 0))
box.cox.axis(0, side="above", 
  grid=T, axis.title="GDP per capita")
box.cox.axis(0, side="right",
  grid=T, axis.title="infant mortality rate per 1000")

qq.plot(logit(infant.mortality/1000))
prob.axis()

qq.plot(logit(infant.mortality/1000))
prob.axis(c(.005, .01, .02, .04, .08, .16))
.KW aplot
.WR
