.\" -*- nroff -*- generated from .Rd format
.BG
.FN av.plots
.FN av.plot
.FN avp
.TL
Added-Variable Plots
.DN
These functions construct added-variable (also called 
partial-regression) plots for  linear and generalized linear
models.

The function intended for direct use is `av.plots' (for which `avp'
is an abbreviation). By default, these functions are used interactively
through a text menu.
  
The model can contain factors and interactions. An added-variable plot can be
drawn for each column of the model matrix, including the constant.

.CS
av.plots(model, variable, ask=missing(variable), one.page=!ask, ...)

avp(...)

av.plot(model, ...)

av.plot.lm(model, variable, labels = names(residuals(model)[!is.na(residuals(
    model))]), identify.points = T, las = par("las"), col = 2, pch = 1,
    lwd = 2, main = "Added-Variable Plot")

av.plot.glm(model, variable, labels = names(residuals(model)[!is.na(residuals(
    model))]), identify.points = T, las = par("las"), col = 2, pch = 1,
    lwd = 2, main = "Added-Variable Plot", type = c("Wang", "Weisberg"))
.RA
.AG model
model object produced by `lm' or `glm'.
.AG variable
variable (if it exists in the search path) or
name of variable. This argument usually is omitted for `avp'
or `av.plots'.
.OA
.AG ask
if `TRUE', a menu is provided in the Commands window for the
user to select the term(s) to plot.
.AG one.page
if `TRUE' (and `ask=F'), put all plots on one
graph.
.AG labels
observation names.
.AG identify.points
if `TRUE', then identify points interactively.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; default is `2'.
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
.AG main
title for plot.
.AG type
if `"Wang"' use the method of Wang (1985);
if `"Weisberg"' use the method in the Arc software associated with
Cook and Weisberg (1999).
.AG ...
arguments to be passed down to `av.plot.lm' or
`av.plot.glm'.
.RT
`NULL'. These functions are used for their side effect: producing
plots.
.SH REFERENCES
Cook, R. D. and Weisberg, S. (1999)
Applied Regression, Including Computing and Graphics. Wiley.
.IP "" 
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.IP "" 
Wang, P C. (1985)
Adding a variable in generalized linear models.
Technometrics 27, 273-276.
.SA
`cr.plots', `ceres.plots', `leverage.plots'
.EX    
av.plots(lm(prestige~income+education+type, data=Duncan))

av.plots(glm(partic != "not.work" ~ hincome + children, 
  data=Womenlf, family=binomial))    
.KW hplot
.KW regression
.WR
