.\" -*- nroff -*- generated from .Rd format
.BG
.FN ceres.plots
.FN ceres.plot
.TL
Ceres Plots
.DN
These functions calculate Ceres plots for linear and generalized
linear model.
.IP
Ceres plots are a generalization of component+residual (partial
residual) plots that are less prone to leakage of nonlinearity
among the predictors.
.IP  
The function intended for direct use is `ceres.plots'. 
By default, this function is used interactively
through a text menu.
.IP  
The model cannot contain interactions, but can contain factors. 
Factors may be present in the model, but Ceres plots cannot be drawn
for them.
  
.CS
ceres.plots(model, variable, ask=missing(variable), one.page=!ask, 
  span=0.5, ...)

ceres.plot(model, ...)

ceres.plot.lm(model, variable, line = T, smooth = T, span = 0.5, iter, 
  las = par("las"), col = 2, pch = 1, lwd = 2, main = "Ceres Plot")

ceres.plot.glm(model, ...)
.RA
.AG model
model object produced by `lm' or `glm'.
.AG variable
variable (if it exists in the search path) or
name of variable. This argument usually is omitted for
`ceres.plots'.
.OA
.AG ask
if `TRUE', a menu is provided in the Commands window for the
user to select the variable(s) to plot, and to modify the span for the smoother
used to draw a nonparametric-regression line on the plot.
.AG one.page
if `TRUE' (and `ask=F'), put all plots on one
graph.
.AG span
span for lowess smoother.
.AG iter
number of robustness iterations for nonparametric-regression smooth;
defaults to 3 for a linear model and to 0 for a non-Gaussian glm.
.AG line
`TRUE' to plot least-squares line.
.AG smooth
`TRUE' to plot nonparametric-regression (lowess) line.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; the default is `2'.
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
.AG main
title for plot.
.AG ...
pass arguments down.
.RT
`NULL'. These functions are used for their side effect: producing
plots.
.SH REFERENCES
Cook, R. D. and Weisberg, S. (1999)
Applied Regression, Including Computing and Graphics. Wiley.
.IP  
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.SA
`cr.plots', `av.plots'
.EX  
ceres.plots(lm(prestige~income+education+type, 
    na.action=na.omit, data=Prestige))  
.KW hplot
.KW regression
.WR
