.\" -*- nroff -*- generated from .Rd format
.BG
.FN cr.plots
.FN cr.plot
.FN crp
.TL
Component+Residual (Partial Residual) Plots
.DN
These functions construct component+residual plots (also called
partial-residual plots) for linear and generalized linear models.
.IP
The function intended for direct use is `cr.plots' (for which `crp'
is an abbreviation). By default, these functions are used interactively
through a text menu.
.IP  
The model cannot contain interactions, but can contain factors. 
Parallel boxplots of the partial residuals are drawn for the levels
of a factor.
  
.CS
cr.plots(model, variable, ask=missing(variable), one.page=!ask, 
  span=0.5, ...)

crp(...)

cr.plot(model, ...)

cr.plot.lm(model, variable, order = 1, line = T, smooth = T, iter, span = 0.5,
    las = par("las"), col = 2, pch = 1, lwd = 2, main = 
    "Component+Residual Plot")

cr.plot.glm(model, ...)
.RA
.AG model
model object produced by `lm' or `glm'.
.AG variable
variable (if it exists in the search path) or
name of variable. This argument usually is omitted for `crp'
or `cr.plots'.
.OA
.AG ask
if `TRUE', a menu is provided in the Commands window for the
user to select the variable(s) to plot, and to modify the span for the smoother
used to draw a nonparametric-regression line on the plot.
.AG one.page
if `TRUE' (and `ask=F'), put all plots on one
graph.
.AG order
order of polynomial regression performed for predictor to be plotted.
.AG line
`TRUE' to plot least-squares line.
.AG smooth
`TRUE' to plot nonparametric-regression (lowess) line.
.AG iter
number of robustness iterations for nonparametric-regression smooth;
defaults to 3 for a linear model and to 0 for a non-Gaussian glm.
.AG span
span for lowess smoother.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; the default is `2'.
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
.AG main
title for plot.
.AG ...
pass arguments down.
.RT
`NULL'. These functions are used for their side effect: producing
plots.
.SH REFERENCES
Cook, R. D. and Weisberg, S. (1999)
Applied Regression, Including Computing and Graphics. Wiley.
.IP
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.SA
`ceres.plots', `av.plots'
.EX  
cr.plots(glm(partic != "not.work" ~ hincome + children, 
  data=Womenlf, family=binomial))

cr.plots(lm(prestige~income+education, data=Prestige), 
  variable="income")  
.KW hplot
.KW regression
.WR
