.\" -*- nroff -*- generated from .Rd format
.BG
.FN qq.plot
.TL
Quantile-Comparison Plots
.DN
Plots empirical quantiles of a variable, or of studentized residuals from
a linear model, against theoretical quantiles of a comparison distribution.
.IP
Draws theoretical quantile-comparison plots for variables and for studentized residuals
from a linear model. A comparison line is drawn on the plot either through the quartiles
of the two distributions, or by robust regression. 
.IP  
Any distribution for which quantile and
density functions exist in S (with prefixes `q' and `d', respectively) may be used. 
Studentized residuals are plotted against the
appropriate t-distribution.
.IP  
The function `qqp' is an abbreviation for `qq.plot'.
.CS
qq.plot(x, ...)

qqp(...)

qq.plot.default(x, distribution = "norm", ylab = deparse(substitute(x)), xlab = paste(
    distribution, "quantiles"), main = "", las = par("las"), envelope = 
    0.95, labels = F, col = 2, lwd = 2, pch = 1, line = c(
    "quartiles", "robust"), ...)

qq.plot.lm(x, main = "", xlab = paste(distribution, "Quantiles"), ylab = paste(
    "Studentized Residuals(", deparse(substitute(x)), ")", sep = ""), 
    distribution = c("t", "norm"), line = c("quartiles", "robust"), las = 
    par("las"), simulate = F, envelope = 0.95, labels = names(rstudent),
    reps = 100, col = 2, lwd = 2, pch = 1, ...)
.RA
.AG x
vector of numeric values or `lm' object.
.OA
.AG distribution
root name of comparison distribution - e.g., `"norm"' for the
normal distribution; `"t"' for the t-distribution.
.AG ylab
label for vertical (empirical quantiles) axis.
.AG xlab
label for horizontal (comparison quantiles) axis.
.AG main
label for plot.
.AG envelope
confidence level for point-wise confidence envelope, or 
`FALSE' for no envelope.
.AG labels
vector of point labels for interactive point identification,
or `FALSE' for no labels.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; the default is `2'.
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
Confidence envelopes are drawn at half this line width.
.AG line
`"quartiles"' to pass a line through the quartile-pairs, or
`"robust"' for a robust-regression line; the latter uses the `rlm'
function in the `MASS' library.
.AG simulate
if `TRUE' calculate confidence envelope by parametric bookstrap;
for `lm' object only. The method is due to Atkinson (1985).
.AG reps
integer; number of bootstrap replications for confidence envelope.
.AG ...
arguments such as `df' to be passed to the appropriate quantile function.
.RT
`NULL'. These functions are used only for their side effect (to make a graph).
.SH REFERENCES
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.IP  
Atkinson, A. C. (1985)
Plots, Transformations, and Regression. Oxford.
.SA
`qqplot', `qqnorm',
`qqline'
.EX
x<-rchisq(100, df=2)
qq.plot(x)
qq.plot(x, dist="chisq", df=2)

mod<-lm(interlocks~assets+sector+nation, data=Ornstein)
qq.plot(mod, sim=T)
.KW distribution
.KW univar
.KW regression
.WR
