.\" -*- nroff -*- generated from .Rd format
.BG
.FN spread.level.plot
.FN slp
.TL
Spread-Level Plots
.DN
Creates plots for examining the possible dependence of
spread on level, or an extension of these plots to the studentized residuals
from linear models.
.IP
Except for linear models, computes the statistics for, and plots, a Tukey spread-level plot
of log(hinge-spread) vs. log(median) for the groups; fits a line to the plot; and calculates a
spread-stabilizing transformation from the slope of the line. 
.IP  
For linear models, plots log(abs(studentized residuals)) vs. log(fitted values).
.IP  
The function `slp' is an abbreviation for `spread.level.plot'.
.CS
spread.level.plot(x, ...)

slp(x, ...)

spread.level.plot.formula(formula, data = NULL, subset, na.action, main = paste(
    "Spread-Level Plot for", varnames[response], "by", varnames[ - response]), 
    ...)

spread.level.plot.default(x, by, robust.line = T, start = 0, xlab = "Median", ylab = 
    "Hinge-Spread", las = 1, main = paste("Spread-Level Plot for", deparse(
    substitute(x)), "by", deparse(substitute(by))), col = 2,
    pch = 1, lwd = 2, ...)

spread.level.plot.lm(x, start = 0, robust.line = T, xlab = "Fitted Values", ylab = 
    "Absolute Studentized Residuals", las = 0, main = paste(
    "Spread-Level Plot for", deparse(substitute(x))), pch = 1, col = 2,
    lwd = 2, ...)
  
print.spread.level.plot(x, ...)
.RA
.AG x
a formula or an `lm' object to be plotted; alternatively a numeric vector.
.AG by
a factor, numeric or character vector defining groups.
.AG formula
a formula of the form `y~x', where `y' is a numeric vector
and `x' is a factor.
.OA
.AG data
an optional data frame containing the variables to be plotted. 
By default the variables are taken from the environment from which 
`spread.level.plot' is called.
.AG subset
an optional vector specifying a subset of observations to be used.
.AG na.action
a function that indicates what should happen when the data contain `NA's. 
.AG robust.line
if `TRUE' a robust line is fit using the `rlm' function in
the `MASS' library; if `FALSE' a line is fit using `lm'.
.AG start
add the constant `start' to each data value.
.AG main
title for the plot.
.AG xlab
label for horizontal axis.
.AG ylab
label for vertical axis.
.AG las
if `0', ticks labels are drawn parallel to the
axis; set to `1' for horizontal labels (see `par').
.AG col
color for points and lines; the default is `2'.
.AG pch
plotting character for points; default is `1' 
(a circle, see `par').
.AG lwd
line width; default is `2' (see `par').
.AG ...
arguments passed to plotting functions.
.RT
A list containing:
.AG Statistics
a matrix with the lower-hinge, median, upper-hinge, and hinge-spread
for each group. (Not for an `lm' object.)
.AG PowerTransformation
spread-stabilizing power transformation, calculated as 1 - slope
of the line fit to the plot.
.SH REFERENCES
Fox, J. (1997)
Applied Regression, Linear Models, and Related Methods. Sage.
.IP
Hoaglin, D. C., Mosteller, F. and Tukey, J. W. (Eds.) (1983)
Understanding Robust and Exploratory Data Analysis. Wiley.
.SA
`hccm', `ncv.test'
.EX
attach(Ornstein)
spread.level.plot(interlocks+1~nation)
##     LowerHinge Median UpperHinge Hinge-Spread 
##  US        2.0    6.0      13.00        11.00
##  UK        4.0    9.0      14.00        10.00
## CAN        6.0   13.0      30.00        24.00
## OTH        4.5   15.5      23.25        18.75
## 
## Suggested power transformation:  0.204133699198547 

mod<-lm(interlocks ~ assets + sector + nation)
slp(mod)
## Warning in spread.level.plot.lm(x): Start =  3 added to fitted values to avoid 0
##  or negative values.
## 
## Suggested power transformation:  0.322216456616146 
.KW hplot
.KW regression
.WR
